//! Various gossip strategies for kitsune

pub mod sharded_gossip;

mod common;
pub use common::*;
